Package: decoder
Type: Package
Title: Decode Coded Variables to Plain Text and the Other Way Around
Version: 1.2.3
Authors@R: 
  person(
    "Erik", 
    "Bulow", 
    email   = "eriklgb@gmail.com",
    role    = c("aut", "cre"),
    comment = c(ORCID = "0000-0002-9973-456X")
  )
Description: Main function "decode" is used to decode coded key values to plain
    text. Function "code" can be used to code plain text to code if there is a
    1:1 relation between the two. The concept relies on 'keyvalue' objects used
    for translation. There are several 'keyvalue' objects included in the areas
    of geographical regional codes, administrative health care unit codes,
    diagnosis codes and more. It is also easy to extend the use by arbitrary 
    code sets.
License: GPL-2
Depends: R (>= 4.1.0)
Suggests: dplyr, DT, testthat, knitr, rmarkdown, tidyr
VignetteBuilder: knitr
Encoding: UTF-8
URL: https://github.com/eribul/decoder,
        https://eribul.github.io/decoder/
BugReports: https://github.com/eribul/decoder/issues
LazyData: TRUE
Language: en-US
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-15 10:07:29 UTC; xbuler
Author: Erik Bulow [aut, cre] (ORCID: <https://orcid.org/0000-0002-9973-456X>)
Maintainer: Erik Bulow <eriklgb@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-15 12:30:02 UTC
Built: R 4.5.2; ; 2026-05-15 13:32:50 UTC; unix
