# Generated by roxygen2: do not edit by hand

S3method(as.keyvalue,data.frame)
S3method(as.keyvalue,default)
S3method(as.keyvalue,keyvalue)
S3method(as.keyvalue,list)
S3method(decode,data.frame)
S3method(decode,default)
S3method(summary,keyvalue)
export(as.key)
export(as.keyvalue)
export(as.value)
export(code)
export(decode)
export(is.key)
export(is.keyvalue)
export(is.value)
export(kungalv2Fyrbodal)
export(kungalv2Storgoteborg)
export(real_names)
export(short_region_names)
