[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/decoder)](https://cran.r-project.org/package=decoder)
[![Build status](https://ci.appveyor.com/api/projects/status/63pi6rykfpsuru1c/branch/master?svg=true)](https://ci.appveyor.com/project/eribul/decoder/branch/master)
![Monthly downloads](http://cranlogs.r-pkg.org/badges/decoder) 
![Total downloads](http://cranlogs.r-pkg.org/badges/grand-total/decoder)
[![Project Status: Active - The project has reached a stable, usable state and is being actively developed.](http://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)

# decoder

The goal of decoder is to decode coded and perhaps cryptical variables to more understandable descriptive labels.

## Installation

You can install the released version of decoder from [CRAN](https://CRAN.R-project.org) with:

``` r
install.packages("decoder")
```

And the development version from [GitHub](https://github.com/eribul/decoder/) with:

``` r
# install.packages("pak")
pak::pkg_install("eribul/decoder")
```
