% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/as.key.R, R/as.value.R
\name{as.key}
\alias{as.key}
\alias{is.key}
\alias{key_and_value}
\alias{as.value}
\alias{is.value}
\title{Coerce to key or value in objects in a key-value pair}
\usage{
as.key(x)

is.key(x)

as.value(x)

is.value(x)
}
\arguments{
\item{x}{a vector}
}
\value{
\code{as.value} returns a value-object (currently the vector itself 
but with class "value").
\code{as.key} returns a key-object (building on \code{value} but with unique 
entries and as character).
}
\description{
Functions to check if an object is a valid key or value in a keyvalue pair, 
or coerce it if possible.
}
