% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extra_functions.R
\name{extra_functions}
\alias{extra_functions}
\alias{kungalv2Storgoteborg}
\alias{kungalv2Fyrbodal}
\alias{real_names}
\alias{short_region_names}
\title{Extra functions to apply to decoded variables using decode}
\usage{
kungalv2Storgoteborg(x)

kungalv2Fyrbodal(x)

real_names(x)

short_region_names(x)
}
\arguments{
\item{x}{The decoded variable to be further processed. 
This argument should not be set by the user.
It is used only internally by the function from which it is called.}
}
\description{
See section "extra_functions" at the \link{decode} help page!
}
