% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/internals.R
\name{pad0}
\alias{pad0}
\title{Pad leading zeros to character}
\usage{
pad0(x, n)
}
\arguments{
\item{x}{character or object that can be coerced to such}

\item{n}{desired length of outcome vector}
}
\value{
Character vector of length \code{n}
}
\description{
Pad leading zeros to character
}
