% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets_keyvalue.R
\docType{data}
\name{hsn}
\alias{hsn}
\title{HSN code (Hälso- och sjukvårdsnamnd)}
\description{
Key-value codes for the HSN:s in VGR valid from 2015.
Based on municipality codes (\code{\link{kommun}}).
Data from 2014-12-17.
}
\details{
Categorization:
\describe{
\item{Norra}{Lysekil, Munkedal, Orust, Sotenäs, Strömstad, Tanum, Bengtsfors,
Dals-Ed, Färgelanda, Mellerud, Åmål, Trollhättan, Uddevalla och Vänersborg}
\item{Västra}{Lilla Edet, Ale, Kungälv, Stenungsund, Tjörn, Öckerö, Härryda,
Mölndal, Partille, Lerum och Alingsås}
\item{Södra}{Herrljunga, Vårgårda, Bollebygd, Borås, Mark, Svenljunga,
Tranemo och Ulricehamn}
\item{Göteborg}{Göteborg}
\item{Östra}{Essunga, Falköping, Grästorp, Götene, Lidköping, Skara, Vara,
Gullspång, Hjo, Karlsborg, Mariestad, Skövde, Tibro, Tidaholm och Töreboda}
}
}
\seealso{
Other key_value_data:
\code{\link{atc}},
\code{\link{distrikt}},
\code{\link{figo}},
\code{\link{forsamling}},
\code{\link{hemort}},
\code{\link{icd10cm}},
\code{\link{icd10se}},
\code{\link{icd7}},
\code{\link{icd7_grov}},
\code{\link{icd9}},
\code{\link{icd9cmd}},
\code{\link{icdo}},
\code{\link{icdo3}},
\code{\link{icdo3_grov}},
\code{\link{klinik}},
\code{\link{kommun}},
\code{\link{kon}},
\code{\link{kva}},
\code{\link{lan}},
\code{\link{m_rtr}},
\code{\link{n_rtr}},
\code{\link{pad}},
\code{\link{patologiavdelning}},
\code{\link{region}},
\code{\link{rockan}},
\code{\link{sida}},
\code{\link{sjukhus}},
\code{\link{sjukhus_inca}},
\code{\link{sjukhus_par}},
\code{\link{sjukvardsomrade}},
\code{\link{snomed}},
\code{\link{snomed3}},
\code{\link{t_rtr}},
\code{\link{tnmgrund}}
}
\concept{key_value_data}
\keyword{datasets}
