% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets_keyvalue.R
\docType{data}
\name{klinik}
\alias{klinik}
\title{Clinic codes}
\description{
Key-value codes for the Swedish clinic types.
Data mainly from url below (taken from the PDF).
Some extra codes are added from Rockan
(290, 291, 292, 446, 921 and 999 for unknown).
}
\seealso{
Other key_value_data:
\code{\link{atc}},
\code{\link{distrikt}},
\code{\link{figo}},
\code{\link{forsamling}},
\code{\link{hemort}},
\code{\link{hsn}},
\code{\link{icd10cm}},
\code{\link{icd10se}},
\code{\link{icd7}},
\code{\link{icd7_grov}},
\code{\link{icd9}},
\code{\link{icd9cmd}},
\code{\link{icdo}},
\code{\link{icdo3}},
\code{\link{icdo3_grov}},
\code{\link{kommun}},
\code{\link{kon}},
\code{\link{kva}},
\code{\link{lan}},
\code{\link{m_rtr}},
\code{\link{n_rtr}},
\code{\link{pad}},
\code{\link{patologiavdelning}},
\code{\link{region}},
\code{\link{rockan}},
\code{\link{sida}},
\code{\link{sjukhus}},
\code{\link{sjukhus_inca}},
\code{\link{sjukhus_par}},
\code{\link{sjukvardsomrade}},
\code{\link{snomed}},
\code{\link{snomed3}},
\code{\link{t_rtr}},
\code{\link{tnmgrund}}
}
\concept{key_value_data}
\keyword{datasets}
