% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/keyvalue_methods.R
\name{summary.keyvalue}
\alias{summary.keyvalue}
\title{Object summary for keyvalue objects}
\usage{
\method{summary}{keyvalue}(object, ...)
}
\arguments{
\item{object}{a keyvalue object}

\item{...}{ignored}
}
\value{
A list with three elements: a summary of the underlying data.frame,
the standard_var_names and possibly a data.frame with all non 1:1 relations.
}
\description{
Objects of type \code{keyvalue11} are summarized as
data.frames with an additional display of possible
\code{standard_var_names}. Objects of type \code{keyvalue}
also gives a list of non 1:1 key-value pairs.
}
\seealso{
\link{keyvalue}
}
